;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "morlock" "20251101.2037"
  "More font-lock keywords for elisp."
  '((emacs "29.1"))
  :url "https://github.com/tarsius/morlock"
  :commit "02759c4d05ef6ec6b05707dab5bfe9a148a2c5ac"
  :revdesc "02759c4d05ef"
  :keywords '("convenience")
  :authors '(("Jonas Bernoulli" . "emacs.morlock@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.morlock@jonas.bernoulli.dev")))
